﻿'''**************************************************************************
' Project  : AvionicsInstrumentControlDemo                                  
' File     : AltimeterInstrumentControl.cs                                  
' Version  : 1                                                              
' Language : C#                                                             
' Summary  : The altimeter instrument control                     
' Creation : 16/06/2008                                                     
' Autor    : Guillaume CHOUTEAU                                             
' History  :                                                                
'''**************************************************************************

Imports System
Imports System.ComponentModel
Imports System.Windows.Forms
Imports System.Collections
Imports System.Drawing
Imports System.Text
Imports System.Data

Namespace AvionicsInstrumentControlDemo
    Public Class AltimeterInstrumentControl
        Inherits InstrumentControl

#Region "Fields"

        ' Parameters
        Private altitude As Integer

        ' Images
        Private bmpCadran As New Bitmap(My.Resources.Altimeter_Background)
        Private bmpSmallNeedle As New Bitmap(My.Resources.SmallNeedleAltimeter)
        Private bmpLongNeedle As New Bitmap(My.Resources.LongNeedleAltimeter)
        Private bmpScroll As New Bitmap(My.Resources.Bandeau_Dérouleur)

#End Region

#Region "Contructor"

        ''' <summary>
        ''' Required designer variable.
        ''' </summary>
        Private components As System.ComponentModel.Container = Nothing

        Public Sub New()
            ' Double bufferisation
            SetStyle(ControlStyles.DoubleBuffer Or ControlStyles.UserPaint Or ControlStyles.AllPaintingInWmPaint, True)
        End Sub

#End Region

#Region "Component Designer generated code"
        ''' <summary>
        ''' Required method for Designer support - do not modify 
        ''' the contents of this method with the code editor.
        ''' </summary>
        Private Overloads Sub InitializeComponent()
            Me.SuspendLayout()
            Me.ResumeLayout(False)

        End Sub
#End Region

#Region "Paint"

        Protected Overrides Sub OnPaint(ByVal pe As PaintEventArgs)
            ' Calling the base class OnPaint
            MyBase.OnPaint(pe)

            ' Pre Display computings
            Dim ptCounter As New Point(35, 135)
            Dim ptRotation As New Point(150, 150)
            Dim ptimgNeedle As New Point(136, 39)

            bmpCadran.MakeTransparent(Color.Yellow)
            bmpLongNeedle.MakeTransparent(Color.Yellow)
            bmpSmallNeedle.MakeTransparent(Color.Yellow)

            Dim alphaSmallNeedle As Double = InterpolPhyToAngle(altitude, 0, 10000, 0, 359)
            Dim alphaLongNeedle As Double = InterpolPhyToAngle(altitude Mod 1000, 0, 1000, 0, 359)

            'INSTANT VB NOTE: The variable scale was renamed since Visual Basic does not handle local variables named the same as class members well:
            Dim scale_Renamed As Single = CSng(Me.Width) / bmpCadran.Width

            ' display counter
            ScrollCounter(pe, bmpScroll, 5, altitude, ptCounter, scale_Renamed)

            ' diplay mask
            Dim maskPen As New Pen(Me.BackColor, 30 * scale_Renamed)
            pe.Graphics.DrawRectangle(maskPen, 0, 0, bmpCadran.Width * scale_Renamed, bmpCadran.Height * scale_Renamed)

            ' display cadran
            pe.Graphics.DrawImage(bmpCadran, 0, 0, CSng(bmpCadran.Width * scale_Renamed), CSng(bmpCadran.Height * scale_Renamed))

            ' display small needle
            RotateImage(pe, bmpSmallNeedle, alphaSmallNeedle, ptimgNeedle, ptRotation, scale_Renamed)

            ' display long needle
            RotateImage(pe, bmpLongNeedle, alphaLongNeedle, ptimgNeedle, ptRotation, scale_Renamed)

        End Sub

#End Region

#Region "Methods"


        ''' <summary>
        ''' Define the physical value to be displayed on the indicator
        ''' </summary>
        ''' <param name="aircraftAltitude">The aircraft altitude in ft</param>
        Public Sub SetAlimeterParameters(ByVal aircraftAltitude As Integer)
            altitude = aircraftAltitude

            Me.Refresh()
        End Sub

#End Region

    End Class
End Namespace
